==> snm-0.5.0.crate: snm-0.5.0/CHANGELOG.md <==
# Changelog

## [v0.4.1](https://github.com/numtostr/snm/tree/v0.4.1) (2021-02-11)

[Full Changelog](https://github.com/numtostr/snm/compare/v0.3.0...v0.4.1)

**Closed issues:**

- snm exec refuse more than 1 argument [\#43](https://github.com/numToStr/snm/issues/43)

**Merged pull requests:**

- chore: package updates [\#44](https://github.com/numToStr/snm/pull/44) ([numToStr](https://github.com/numToStr))
- fix shell examples in readme [\#42](https://github.com/numToStr/snm/pull/42) ([ScottLNorvell](https://github.com/ScottLNorvell))

## [v0.3.0](https://github.com/numtostr/snm/tree/v0.3.0) (2021-01-13)

[Full Changelog](https://github.com/numtostr/snm/compare/v0.2.0...v0.3.0)

**Closed issues:**

- Support `engines` key from `package.json` [\#38](https://github.com/numToStr/snm/issues/38)

**Merged pull requests:**

- Support `package.json` in `snm use` [\#40](https://github.com/numToStr/snm/pull/40) ([numToStr](https://github.com/numToStr))
- Improved perf of `snm use` when reading `.nvmrc` or `.node-version` [\#39](https://github.com/numToStr/snm/pull/39) ([numToStr](https://github.com/numToStr))

## [v0.2.0](https://github.com/numtostr/snm/tree/v0.2.0) (2021-01-05)

[Full Changelog](https://github.com/numtostr/snm/compare/v0.1.9...v0.2.0)

**Closed issues:**

- Add `tj/n` style version help in `snm --help` [\#37](https://github.com/numToStr/snm/issues/37)
- Add `a` as an alias to `alias` command [\#36](https://github.com/numToStr/snm/issues/36)

**Merged pull requests:**

- improved help and added missing doc comments [\#35](https://github.com/numToStr/snm/pull/35) ([numToStr](https://github.com/numToStr))
- Upgrade ureq to v2 [\#34](https://github.com/numToStr/snm/pull/34) ([numToStr](https://github.com/numToStr))
- Added bash install script for Linux and macOS [\#33](https://github.com/numToStr/snm/pull/33) ([numToStr](https://github.com/numToStr))

## [v0.1.9](https://github.com/numtostr/snm/tree/v0.1.9) (2021-01-03)

[Full Changelog](https://github.com/numtostr/snm/compare/v0.1.8...v0.1.9)

**Merged pull requests:**

- pull\_request workflow file [\#30](https://github.com/numToStr/snm/pull/30) ([numToStr](https://github.com/numToStr))
- Revert "Added workflow on pull request" [\#29](https://github.com/numToStr/snm/pull/29) ([numToStr](https://github.com/numToStr))
- fixed windows binary not working [\#28](https://github.com/numToStr/snm/pull/28) ([numToStr](https://github.com/numToStr))
- Added workflow on pull request [\#27](https://github.com/numToStr/snm/pull/27) ([numToStr](https://github.com/numToStr))

## [v0.1.8](https://github.com/numtostr/snm/tree/v0.1.8) (2021-01-02)

[Full Changelog](https://github.com/numtostr/snm/compare/e3cd4480038682a828a16a0e48f5f5bafe1b1684...v0.1.8)

**Closed issues:**

- Release 0.1.0 [\#25](https://github.com/numToStr/snm/issues/25)
- lts/\* pattern in `snm unalias` [\#16](https://github.com/numToStr/snm/issues/16)
- Allow alias and lts\* in `snm uninstall` [\#15](https://github.com/numToStr/snm/issues/15)
- Add README [\#14](https://github.com/numToStr/snm/issues/14)
- snm unalias [\#13](https://github.com/numToStr/snm/issues/13)
- Make some defaults aliases [\#12](https://github.com/numToStr/snm/issues/12)
- Allow aliases in `snm use` [\#10](https://github.com/numToStr/snm/issues/10)
- Support .nvmrc and .node-version [\#9](https://github.com/numToStr/snm/issues/9)
- Allow lts-\* and lts/\* installations [\#8](https://github.com/numToStr/snm/issues/8)
- Bubble up the errors [\#6](https://github.com/numToStr/snm/issues/6)
- GHA for release [\#5](https://github.com/numToStr/snm/issues/5)
- Windows support? [\#4](https://github.com/numToStr/snm/issues/4)
- Colorful output [\#2](https://github.com/numToStr/snm/issues/2)
- Tests [\#1](https://github.com/numToStr/snm/issues/1)

**Merged pull requests:**

- Added mod tests [\#26](https://github.com/numToStr/snm/pull/26) ([numToStr](https://github.com/numToStr))
- Towards 0.1.0 release [\#24](https://github.com/numToStr/snm/pull/24) ([numToStr](https://github.com/numToStr))
- Windows support [\#11](https://github.com/numToStr/snm/pull/11) ([numToStr](https://github.com/numToStr))
- Error bubbles [\#7](https://github.com/numToStr/snm/pull/7) ([numToStr](https://github.com/numToStr))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> snm-0.5.2.crate: snm-0.5.2/CHANGELOG.md <==
# Changelog

## [v0.5.0](https://github.com/numtostr/snm/tree/v0.5.0) (2021-05-07)

[Full Changelog](https://github.com/numtostr/snm/compare/v0.4.1...v0.5.0)

**Merged pull requests:**

- feat: download progress bar [\#46](https://github.com/numToStr/snm/pull/46) ([numToStr](https://github.com/numToStr))
- fix typo in downloader [\#45](https://github.com/numToStr/snm/pull/45) ([numToStr](https://github.com/numToStr))

## [v0.4.1](https://github.com/numtostr/snm/tree/v0.4.1) (2021-02-11)

[Full Changelog](https://github.com/numtostr/snm/compare/v0.3.0...v0.4.1)

**Closed issues:**

- snm exec refuse more than 1 argument [\#43](https://github.com/numToStr/snm/issues/43)

**Merged pull requests:**

- chore: package updates [\#44](https://github.com/numToStr/snm/pull/44) ([numToStr](https://github.com/numToStr))
- fix shell examples in readme [\#42](https://github.com/numToStr/snm/pull/42) ([ScottLNorvell](https://github.com/ScottLNorvell))

## [v0.3.0](https://github.com/numtostr/snm/tree/v0.3.0) (2021-01-13)

[Full Changelog](https://github.com/numtostr/snm/compare/v0.2.0...v0.3.0)

**Closed issues:**

- Support `engines` key from `package.json` [\#38](https://github.com/numToStr/snm/issues/38)

**Merged pull requests:**

- Support `package.json` in `snm use` [\#40](https://github.com/numToStr/snm/pull/40) ([numToStr](https://github.com/numToStr))
- Improved perf of `snm use` when reading `.nvmrc` or `.node-version` [\#39](https://github.com/numToStr/snm/pull/39) ([numToStr](https://github.com/numToStr))

## [v0.2.0](https://github.com/numtostr/snm/tree/v0.2.0) (2021-01-05)

[Full Changelog](https://github.com/numtostr/snm/compare/v0.1.9...v0.2.0)

**Closed issues:**

- Add `tj/n` style version help in `snm --help` [\#37](https://github.com/numToStr/snm/issues/37)
- Add `a` as an alias to `alias` command [\#36](https://github.com/numToStr/snm/issues/36)

**Merged pull requests:**

- improved help and added missing doc comments [\#35](https://github.com/numToStr/snm/pull/35) ([numToStr](https://github.com/numToStr))
- Upgrade ureq to v2 [\#34](https://github.com/numToStr/snm/pull/34) ([numToStr](https://github.com/numToStr))
- Added bash install script for Linux and macOS [\#33](https://github.com/numToStr/snm/pull/33) ([numToStr](https://github.com/numToStr))

## [v0.1.9](https://github.com/numtostr/snm/tree/v0.1.9) (2021-01-03)

[Full Changelog](https://github.com/numtostr/snm/compare/v0.1.8...v0.1.9)

**Merged pull requests:**

- pull\_request workflow file [\#30](https://github.com/numToStr/snm/pull/30) ([numToStr](https://github.com/numToStr))
- Revert "Added workflow on pull request" [\#29](https://github.com/numToStr/snm/pull/29) ([numToStr](https://github.com/numToStr))
- fixed windows binary not working [\#28](https://github.com/numToStr/snm/pull/28) ([numToStr](https://github.com/numToStr))
- Added workflow on pull request [\#27](https://github.com/numToStr/snm/pull/27) ([numToStr](https://github.com/numToStr))

## [v0.1.8](https://github.com/numtostr/snm/tree/v0.1.8) (2021-01-02)

[Full Changelog](https://github.com/numtostr/snm/compare/e3cd4480038682a828a16a0e48f5f5bafe1b1684...v0.1.8)

**Closed issues:**

- Release 0.1.0 [\#25](https://github.com/numToStr/snm/issues/25)
- lts/\* pattern in `snm unalias` [\#16](https://github.com/numToStr/snm/issues/16)
- Allow alias and lts\* in `snm uninstall` [\#15](https://github.com/numToStr/snm/issues/15)
- Add README [\#14](https://github.com/numToStr/snm/issues/14)
- snm unalias [\#13](https://github.com/numToStr/snm/issues/13)
- Make some defaults aliases [\#12](https://github.com/numToStr/snm/issues/12)
- Allow aliases in `snm use` [\#10](https://github.com/numToStr/snm/issues/10)
- Support .nvmrc and .node-version [\#9](https://github.com/numToStr/snm/issues/9)
- Allow lts-\* and lts/\* installations [\#8](https://github.com/numToStr/snm/issues/8)
- Bubble up the errors [\#6](https://github.com/numToStr/snm/issues/6)
- GHA for release [\#5](https://github.com/numToStr/snm/issues/5)
- Windows support? [\#4](https://github.com/numToStr/snm/issues/4)
- Colorful output [\#2](https://github.com/numToStr/snm/issues/2)
- Tests [\#1](https://github.com/numToStr/snm/issues/1)

**Merged pull requests:**

- Added mod tests [\#26](https://github.com/numToStr/snm/pull/26) ([numToStr](https://github.com/numToStr))
- Towards 0.1.0 release [\#24](https://github.com/numToStr/snm/pull/24) ([numToStr](https://github.com/numToStr))
- Windows support [\#11](https://github.com/numToStr/snm/pull/11) ([numToStr](https://github.com/numToStr))
- Error bubbles [\#7](https://github.com/numToStr/snm/pull/7) ([numToStr](https://github.com/numToStr))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
